@@ -6,6 +6,7 @@ import collections
 import atexit
 import os
 import os.path
+import re
 from rez.exceptions import RezError
 from rez.vendor.progress.bar import Bar
 from rez.vendor.six import six
@@ -40,14 +41,31 @@ def dedup(seq):
             yield item
 
 
+_find_unsafe = re.compile(r'[^\w@%+=:,./-]').search
+
+
+def double_quote(s):
+    """A backport of shlex.quote (py 3.8+) that double-quotes instead of single.
+
+    We need this in order to escape commands in resolved shells. For example,
+    the command `rez-env -- echo 'hey $YOU'` needs to execute the equivalent
+    command `echo "hey $YOU"` within the runtime. The single quotes in the
+    initial command are only used to stop early expansion of $YOU, but within
+    the rez env, we default to expansion.
+    """
+    if not s:
+        return "''"
+    if _find_unsafe(s) is None:
+        return s
+
+    # use double quotes, and put double quotes into single quotes
+    # the string $"b is then quoted as "$"'"'"b"
+    return '"' + s.replace('"', '"\'"\'"') + '"'
+
+
 def shlex_join(value):
-    import pipes
-
-    def quote(s):
-        return pipes.quote(s) if '$' not in s else s
-
     if is_non_string_iterable(value):
-        return ' '.join(quote(x) for x in value)
+        return ' '.join(double_quote(x) for x in value)
     else:
         return str(value)
 
